summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChris Phan <cphan@us.ibm.com>2013-03-15 14:03:50 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-04-02 17:30:47 -0500
commit036dc9110acd7977f4b20809b26632e01d4304ca (patch)
treec06697255a7032250507c8063647a9ca1cf592a1
parent38afab26d3e754f5ef0a10c6fa8984bbefe6b454 (diff)
downloadtalos-hostboot-036dc9110acd7977f4b20809b26632e01d4304ca.tar.gz
talos-hostboot-036dc9110acd7977f4b20809b26632e01d4304ca.zip
Change PRDF patch path from /nfs/data/prdf/ to /maint/data/prdf/
Change-Id: Ia8d478db6933a8a8393b436206a92d2fdfd617dc Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/3592 Tested-by: Jenkins Server Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com> Reviewed-by: Bradley W. Bishop <bradleyb@us.ibm.com> Reviewed-by: Zane Shelley <zshelle@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
-rwxr-xr-xsrc/usr/diag/prdf/common/framework/rule/prdrLoadChipCache.C22
1 files changed, 9 insertions, 13 deletions
diff --git a/src/usr/diag/prdf/common/framework/rule/prdrLoadChipCache.C b/src/usr/diag/prdf/common/framework/rule/prdrLoadChipCache.C
index 6d29bdf4e..1313f9513 100755
--- a/src/usr/diag/prdf/common/framework/rule/prdrLoadChipCache.C
+++ b/src/usr/diag/prdf/common/framework/rule/prdrLoadChipCache.C
@@ -77,7 +77,7 @@ namespace Prdr
{
// NOTE: to patch PRF files require rebuilding
// entire Hostboot image and put in a special
// location on FSP /nfs mount.
// FIXME: if we need to patch prf files directly
// on Hostboot, need to discuss with Patrick
// about a possibility of creating a new PNOR
@@ -119,22 +119,18 @@ namespace Prdr
if (NULL != l_errl) break;
- // Read /nfs/data/... directory path
- size_t l_nfsPathSize = 256;
- char l_nfsPath[256] = { '\0' };
- l_errl = UtilReg::read("fstp/NFS_Root",
- (void *) l_nfsPath,
- l_nfsPathSize);
-
- strncat(l_nfsPath, "prdf/", 255);
- strncat(l_nfsPath, i_file, 255);
- strncat(l_nfsPath, ".prf", 255);
+ // Read /maint/data/... directory path
+ // for any prf file patch
+ char l_patchPath[256] = { '\0' };
+ strcpy(l_patchPath, "/maint/data/prdf/");
+ strncat(l_patchPath, i_file, 255);
+ strncat(l_patchPath, ".prf", 255);
if (NULL != l_errl) break;
// Open File to read chip.
- UtilFile l_ruleFile(l_nfsPath);
- if (!l_ruleFile.exists()) // check for NFS file.
+ UtilFile l_ruleFile(l_patchPath);
+ if (!l_ruleFile.exists()) // check for patch file.
{
l_ruleFile.Open(l_rootPath, "r");
}
@@ -77,7 +77,7 @@ namespace Prdr
// NOTE: to patch PRF files require rebuilding
// entire Hostboot image and put in a special
- // location on FSP /nfs mount.
+ // location on FSP /maint/ mount.
// FIXME: if we need to patch prf files directly
// on Hostboot, need to discuss with Patrick
OpenPOWER on IntegriCloud